# Hosting your Blog

home Home
pages elcato
pages blog
pages hosting

## Gitlab Pages

Create this file in your project root, GitLabs ci runner will then deploy the results to gitlab pages. The URL will be available at https: USER.gitlab.ioREPO replacing USER and REPO with the correct values.

     1
     2
     3
     4
     5
     6
     7
     8
     9
    10
    11
      image: python3.6
      pages:
        stage: deploy
        script:
        - pip install elcato
        - elcato init --path=public/
        artifacts:
          paths:
          - public
        only:
        - master

## Docker container

Create a docker-compose file in your blogs root.

    1
    2
    3
    4
    5
    version: '2'
    services:
      image: nginx
        volumes:
          - ./site:/usr/share/nginx/html

Run the below command in you blog's root to launch your web server.

    1
    docker-compose up

rss_feed